@@ -79,39 +79,46 @@ if (exists("updateAllForms") && updateAllForms) {
 #' begin and to document your decisions, rationale. A template such as
 #' this one can be employed to think about what you want to do and how,
 #' and subsequently, if you wish, you can submit the finished preregistration
-#' to a registry, such as OSF’s (https://osf.io/registries/). This template
+#' to a registry, such as OSF's (https://osf.io/registries/). This template
 #' was developed to aid the preregistration of quantitative ethnographic
 #' studies, but due to its modular nature, it can be employed for qualitative
 #' studies as well.
 #'
+#' @aliases form_preregQE_v0_93 form_preregQE_v0_94
 #' @format A (pre)registration form specification
 #' @source \doi{http://dx.doi.org/10.23668/psycharchives.4584}
 #'
-"form_preregQE_v0_93"
+"form_preregQE_v0_94"
 
 
 ### Preregistration Template for Qualitative and Quantitative Ethnographic Studies
 if (exists("updateAllForms") && updateAllForms) {
+
   gSheet_url <-
-    "https://docs.google.com/spreadsheets/d/1l3N0bWnKlRvXuHO-JFg3XHdWzgJWLNli90bnUUa5op4";
+    # v0.93 "https://docs.google.com/spreadsheets/d/1l3N0bWnKlRvXuHO-JFg3XHdWzgJWLNli90bnUUa5op4";
+    "https://docs.google.com/spreadsheets/d/1ArM4kwHC9meVSiwCkR-WzF6m8YkwgEYyfxllhEz2vro";
 
   localBackupFile <-
     here::here(
-      "inst", "extdata", "preregr-form_preregQE_v0_93.xlsx"
+      "inst", "extdata",
+      #"preregr-form_preregQE_v0_93.xlsx"
+      "preregr-form_preregQE_v0_94.xlsx"
     );
 
-  form_preregQE_v0_93 <-
+  #form_preregQE_v0_93 <-
+  form_preregQE_v0_94 <-
     preregr::form_fromSpreadsheet(
       gSheet_url,
       localBackup = localBackupFile,
       silent=FALSE
     );
 
-  # preregr::prereg_spec_to_yaml(
-  #
-  # );
+  usethis::use_data(
+    #form_preregQE_v0_93,
+    form_preregQE_v0_94,
+    overwrite=TRUE
+  );
 
-  usethis::use_data(form_preregQE_v0_93, overwrite=TRUE);
 }
 
 #' OSF Prereg form
@@ -160,8 +167,7 @@ if (exists("updateAllForms") && updateAllForms) {
 
 #' Inclusive General-Purpose Registration Form
 #'
-#' This Inclusive General-Purpose Registration Form is intended as a
-#' general-purpose registration form. The form is designed to be applicable
+#' This Inclusive General-Purpose Registration Form is designed to be applicable
 #' across disciplines (i.e., psychology, economics, law, physics, or any other
 #' field) and across study types (i.e., qualitative studies, quantitative
 #' studies, experiments, systematic reviews, case studies, archive studies,
@@ -170,11 +176,14 @@ if (exists("updateAllForms") && updateAllForms) {
 #' no specialized form or registration platform is available. If at all
 #' possible, it is recommended to use a specialized form, since this
 #' inclusive general-purpose registration form achieves that inclusiveness
-#' and general-purposeness at the cost of specificity.
+#' and general-purposeness at the cost of specificity and comprehensiveness.
+#' Still, if specialized forms don't fit for your study, this form may be a
+#' good backup.
 #'
+#' @aliases form_generalPurpose_v1 form_generalPurpose_v1_1
 #' @format A (pre)registration form specification
 #'
-"form_generalPurpose_v1"
+"form_generalPurpose_v1_1"
 
 #' An example (pre)registration specification using the Inclusive
 #' General-Purpose Registration Form
@@ -190,31 +199,36 @@ if (exists("updateAllForms") && updateAllForms) {
 if (exists("updateAllForms") && updateAllForms) {
 
   gSheet_url <-
-    "https://docs.google.com/spreadsheets/d/1YFqO9Nr-A3UI1FEkn99z8s2LB7VhE7Lp9gdBiOuHAgA";
+    # v1.0 "https://docs.google.com/spreadsheets/d/1YFqO9Nr-A3UI1FEkn99z8s2LB7VhE7Lp9gdBiOuHAgA";
+    "https://docs.google.com/spreadsheets/d/1xmgNFItwtoqD-MMW3-ySkmnSqA6gvrxhuuCj5GnkoXU";
 
   localBackupFile <-
     here::here(
-      "inst", "extdata", "preregr-form_generalPurpose_v1.xlsx"
+      "inst", "extdata", "preregr-form_generalPurpose_v1_1.xlsx"
     );
 
   yamlFile <-
     here::here(
-      "inst", "extdata", "preregr-spec-example1.yml"
+      "inst", "extdata", "preregr-spec-example1_1.yml"
     );
 
-  form_generalPurpose_v1 <-
+  form_generalPurpose_v1_1 <-
     preregr::form_fromSpreadsheet(
       gSheet_url,
       localBackup = localBackupFile,
       silent=FALSE
     );
 
-  usethis::use_data(form_generalPurpose_v1, overwrite=TRUE);
+  usethis::use_data(
+    # form_generalPurpose_v1,
+    form_generalPurpose_v1_1,
+    overwrite=TRUE
+  );
 
   ### We also store a completed version of this form; also in in YAML and JSON
   examplePrereg_1 <-
     preregr::prereg_initialize(
-      form_generalPurpose_v1
+      form_generalPurpose_v1_1
     );
 
   examplePrereg_1 <-
@@ -242,3 +256,69 @@ if (exists("updateAllForms") && updateAllForms) {
   usethis::use_data(examplePrereg_1, overwrite=TRUE);
 
 }
+
+#' Preregistration Template for Secondary Data Analysis
+#'
+#' Please cite the associated paper when using this preregistration
+#' template (see https://doi.org/10.15626/MP.2020.2625).
+#'
+#' @format A (pre)registration specification
+#'
+"form_prereg2D_v1"
+
+### Inclusive General-Purpose Registration Form
+if (exists("updateAllForms") && updateAllForms) {
+
+  gSheet_url <-
+    "https://docs.google.com/spreadsheets/d/1-h4aT6i_K09bv-1da1JhT6lKXEjYcP9W";
+
+  localBackupFile <-
+    here::here(
+      "inst", "extdata", "preregr-form_prereg2D_v1.xlsx"
+    );
+
+  form_prereg2D_v1 <-
+    preregr::form_fromSpreadsheet(
+      gSheet_url,
+      localBackup = localBackupFile,
+      silent=FALSE
+    );
+
+  usethis::use_data(form_prereg2D_v1, overwrite=TRUE);
+
+}
+
+#' A mostly empty example form specification
+#'
+#' This form specification is mostly empty, so it can be a
+#' useful start if you want to create your own form. The accompanying
+#' Google Sheet, which you can also copy, is
+#' <https://docs.google.com/spreadsheets/d/14Qbak7JbBhTqmJaMgJ4tU9ZROaBbUfq37_UzkoHnM60>
+#'
+#' @format A (pre)registration specification
+#'
+"form_almostEmptyForm"
+
+### Inclusive General-Purpose Registration Form
+if (exists("updateAllForms") && updateAllForms) {
+
+  gSheet_url <-
+    "https://docs.google.com/spreadsheets/d/14Qbak7JbBhTqmJaMgJ4tU9ZROaBbUfq37_UzkoHnM60";
+
+  localBackupFile <-
+    here::here(
+      "inst", "extdata", "preregr-form_almostEmptyForm_v1.xlsx"
+    );
+
+  form_almostEmptyForm <-
+    preregr::form_fromSpreadsheet(
+      gSheet_url,
+      localBackup = localBackupFile,
+      silent=FALSE
+    );
+
+  usethis::use_data(form_almostEmptyForm, overwrite=TRUE);
+
+}
+
+
